@@ -42,7 +42,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
  
   #========================================
   # Extracting non-wear and clipping and make decision on which additional time needs to be considered non-wear
-  out = g.weardec(M,wearthreshold,ws2)
+  out = g.weardec(M, wearthreshold, ws2, nonWearEdgeCorrection = params_cleaning[["nonWearEdgeCorrection"]])
   r1 = out$r1 #non-wear
   r2 = out$r2 #clipping
   r3 = out$r3 #additional non-wear
@@ -186,6 +186,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
   # Impute ws3 second data based on ws2 minute estimates of non-wear time
   r5 = r1 + r2 + r3 + r4
   r5[which(r5 > 1) ] = 1
+  r5[which(metalong$nonwearscore == -1) ] = -1 # expanded data with expand_tail_max_hours
   r5long = matrix(0,length(r5),(ws2/ws3)) #r5long is the same as r5, but with more values per period of time
   r5long = replace(r5long,1:length(r5long),r5)
   r5long = t(r5long)
@@ -206,7 +207,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
     # The average day is used for imputation and defined relative to the starttime of the measurement
     # irrespective of dayborder as used in other parts of GGIR
     metrimp = metr = as.numeric(as.matrix(metashort[, mi]))
-    is.na(metr[which(r5long == 1)]) = T #turn all values of metr to na if r5long is 1
+    is.na(metr[which(r5long != 0)]) = T #turn all values of metr to na if r5long is different to 0 (it now leaves the expanded time with expand_tail_max out of the averageday calculation)
     imp = matrix(NA,wpd,ceiling(length(metr)/wpd)) #matrix used for imputation of seconds
     ndays = ncol(imp) #number of days (rounded upwards)
     nvalidsec = matrix(0,wpd,1)
@@ -236,8 +237,9 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
         }
       }
       dim(imp) = c(length(imp),1)
-      #      imp = imp[-c(which(is.na(as.numeric(as.character(imp))) == T))] 
-      metashort[,mi] = as.numeric(imp[1:nrow(metashort)]) #to cut off the latter part of the last day used as a dummy data
+      #      imp = imp[-c(which(is.na(as.numeric(as.character(imp))) == T))]
+      toimpute = which(r5long != -1)       # do not impute the expanded time with expand_tail_max_hours
+      metashort[toimpute, mi] = as.numeric(imp[toimpute]) #to cut off the latter part of the last day used as a dummy data
     } else {
       dcomplscore = length(which(r5long == 0))/wpd
     }
@@ -246,7 +248,7 @@ g.impute = function(M, I, params_cleaning = c(), desiredtz = "",
   
   metashort[,2:ncol(metashort)] = round(metashort[,2:ncol(metashort)], digits = n_decimal_places)
   rout = data.frame(r1 = r1, r2 = r2, r3 = r3, r4 = r4, r5 = r5, stringsAsFactors = TRUE)
-  invisible(list(metashort = metashort, rout = rout, dcomplscore = dcomplscore, 
+  invisible(list(metashort = metashort, rout = rout, r5long = r5long, dcomplscore = dcomplscore, 
                  averageday = averageday, windowsizes = windowsizes, strategy = params_cleaning[["strategy"]],
                  LC = LC, LC2 = LC2, hrs.del.start = params_cleaning[["hrs.del.start"]], hrs.del.end = params_cleaning[["hrs.del.end"]],
                  maxdur = params_cleaning[["maxdur"]]))
