@@ -1,7 +1,7 @@
 g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                    studyname = c(), myfun = c(),
                    params_metrics = c(), params_rawdata = c(),
-                   params_cleaning = c(), params_general = c(), ...) {
+                   params_cleaning = c(), params_general = c(), verbose = TRUE, ...) {
 
   #----------------------------------------------------------
   # Extract and check parameters
@@ -27,7 +27,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
     }
   }
 
-  if (f1 == 0) cat("\nWarning: f1 = 0 is not a meaningful value")
+  if (f1 == 0) warning("\nWarning: f1 = 0 is not a meaningful value")
   filelist = isfilelist(datadir)
   if (filelist == FALSE) {
     if (dir.exists(datadir) == FALSE) {
@@ -42,6 +42,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
   dir2fn = datadir2fnames(datadir,filelist)
   fnames = dir2fn$fnames
   fnamesfull = dir2fn$fnamesfull
+
   # check whether these are movisens files
   is.mv = ismovisens(datadir)
   if (filelist == FALSE & is.mv == TRUE) {
@@ -52,7 +53,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
   bigEnough = which(filesizes/1e6 > params_rawdata[["minimumFileSizeMB"]])
   fnamesfull = fnamesfull[bigEnough]
   fnames = fnames[bigEnough]
-  
+
   # create output directory if it does not exist
   if (filelist == TRUE) {
     if (length(studyname) == 0) {
@@ -80,21 +81,17 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
   # check access permissions
   Nfile_without_readpermission = length(which(file.access(paste0(fnamesfull), mode = 4) == -1)) #datadir,"/",
   if (Nfile_without_readpermission > 0) {
-    cat("\nChecking that user has read access permission for all files in data directory: No")
+    if (verbose == TRUE) cat("\nChecking that user has read access permission for all files in data directory: No")
     warning(paste0("\nThere are/is ", Nfile_without_readpermission,
                    " file(s) in directory specified with argument datadir for which the user does not have read access permission"))
   } else {
-    cat("\nChecking that user has read access permission for all files in data directory: Yes")
+    if (verbose == TRUE) cat("\nChecking that user has read access permission for all files in data directory: Yes")
   }
   if (file.access(outputdir, mode = 2) == 0) {
-    cat("\nChecking that user has write access permission for directory specified by argument outputdir: Yes\n")
+    if (verbose == TRUE) cat("\nChecking that user has write access permission for directory specified by argument outputdir: Yes\n")
   } else {
     stop("\nUser does not seem to have write access permissions for the directory specified by argument outputdir.\n")
   }
-  f16 = function(X) {
-    out = unlist(strsplit(X,"/"))
-    f16 = out[length(out)]
-  }
   f17 = function(X) {
     out = unlist(strsplit(X, "/"))
     f17 = out[(length(out) - 1)]
@@ -102,7 +99,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
   tmp5 = tmp6 = rep(0, length(fnamesfull))
   if (length(fnamesfull) > 0) {
     if (is.mv == FALSE) {
-      fnamesshort = apply(X = as.matrix(fnamesfull),MARGIN = 1, FUN = f16)
+      fnamesshort = basename(fnamesfull)
       phase = apply(X = as.matrix(fnamesfull), MARGIN = 1, FUN = f17)
       for (i in 1:length(fnames)) {
         ff = unlist(strsplit(fnames[i], "/"))
@@ -142,17 +139,21 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
   } else {
     ffdone = c()
   }
-  fnames = sort(fnames)
-  fnamesfull = sort(fnamesfull)
+  # Following lines turned off because does not work when using subfolders
+  # It seems best to leave sorting efforts until the very end when reports are created
+  # fnames = sort(fnames)
+  # fnamesfull = sort(fnamesfull)
+
+
   #=========================================================
   # Declare core functionality, which at the end of this g.part1 is either
   # applied to the file in parallel with foreach or serially with a loop
   main_part1 = function(i, params_metrics, params_rawdata,
                         params_cleaning, params_general, datadir, fnames, fnamesfull,
                         outputdir, myfun, filelist, studyname, ffdone, tmp5, tmp6,
-                        use.temp, daylimit, path3, outputfolder, is.mv) {
+                        use.temp, daylimit, path3, outputfolder, is.mv, verbose) {
     tail_expansion_log = NULL
-    if (params_general[["print.filename"]] == TRUE) {
+    if (params_general[["print.filename"]] == TRUE & verbose == TRUE) {
       cat(paste0("\nFile name: ",fnames[i]))
     }
     # if (filelist == TRUE) {
@@ -178,6 +179,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
     if (length(withoutRD) > 1) {
       fnames_without = withoutRD[1]
     }
+
     if (length(ffdone) > 0) {
       ffdone_without = 1:length(ffdone) #dummy variable
       for (index in 1:length(ffdone)) {
@@ -200,7 +202,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
     options(warn = 0) #turn on warnings
     if (params_general[["overwrite"]] == TRUE) skip = 0
     if (skip == 0) { #if skip = 1 then skip the analysis as you already processed this file
-      cat(paste0("\nP1 file ",i))
+      if (verbose == TRUE) cat(paste0("\nP1 file ",i))
       turn.do.cal.back.on = FALSE
       if (params_rawdata[["do.cal"]] == TRUE & I$dformc == 3) { # do not do the auto-calibration for wav files (because already done in pre-processign)
         params_rawdata[["do.cal"]] = FALSE
@@ -227,8 +229,8 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       #--------------------------------------
       if (params_rawdata[["do.cal"]] == TRUE & length(params_rawdata[["backup.cal.coef"]]) == 0) {
         # cat(paste0("\n",rep('-',options()$width),collapse=''))
-        cat("\n")
-        cat("\nInvestigate calibration of the sensors with function g.calibrate:\n")
+        if (verbose == TRUE) cat("\n")
+        if (verbose == TRUE) cat("\nInvestigate calibration of the sensors with function g.calibrate:\n")
         C = g.calibrate(datafile,
                         params_rawdata = params_rawdata,
                         params_general = params_general,
@@ -272,7 +274,9 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       # the end-user can generate this document based on calibration analysis done with the same accelerometer device.
       if (length(params_rawdata[["backup.cal.coef"]]) > 0 & check.backup.cal.coef == TRUE) {
         bcc.data = read.csv(params_rawdata[["backup.cal.coef"]])
-        if (isTRUE(params_rawdata[["do.cal"]])) cat("\nRetrieving previously derived calibration coefficients")
+        if (isTRUE(params_rawdata[["do.cal"]]) & verbose == TRUE) {
+          cat("\nRetrieving previously derived calibration coefficients")
+        }
         bcc.data$filename = as.character(bcc.data$filename)
         for (nri in 1:nrow(bcc.data)) {
           tmp = unlist(strsplit(as.character(bcc.data$filename[nri]),"meta_"))
@@ -291,18 +295,22 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
           C$scale = as.numeric(bcc.data[bcc.i[1],bcc.scalei])
           C$offset = as.numeric(bcc.data[bcc.i[1],bcc.offseti])
           C$tempoffset =  as.numeric(bcc.data[bcc.i[1],bcc.temp.offseti])
-          cat(paste0("\nRetrieved Calibration error (g) before: ",as.numeric(bcc.data[bcc.i[1],bcc.cal.error.start])))
-          cat(paste0("\nRetrieved Callibration error (g) after: ",as.numeric(bcc.data[bcc.i[1],bcc.cal.error.end])))
-          cat(paste0("\nRetrieved offset correction ",c("x","y","z"),": ",C$offset))
-          cat(paste0("\nRetrieved scale correction ",c("x","y","z"),": ",C$scale))
-          cat(paste0("\nRetrieved tempoffset correction ",c("x","y","z"),": ",C$tempoffset))
-          cat("\n")
+          if (verbose == TRUE) {
+            cat(paste0("\nRetrieved Calibration error (g) before: ",as.numeric(bcc.data[bcc.i[1],bcc.cal.error.start])))
+            cat(paste0("\nRetrieved Callibration error (g) after: ",as.numeric(bcc.data[bcc.i[1],bcc.cal.error.end])))
+            cat(paste0("\nRetrieved offset correction ",c("x","y","z"),": ",C$offset))
+            cat(paste0("\nRetrieved scale correction ",c("x","y","z"),": ",C$scale))
+            cat(paste0("\nRetrieved tempoffset correction ",c("x","y","z"),": ",C$tempoffset))
+            cat("\n")
+          }
         } else {
           # cat("\nNo matching filename found in backup.cal.coef\n")
           # cat(paste0("\nCheck that filename ",fnames[i]," exists in the csv-file\n"))
           if (params_rawdata[["do.cal"]] == TRUE) { # If no matching filename could be found, then try to derive the calibration coeficients in the normal way
-            cat("\n")
-            cat("\nInvestigate calibration of the sensors with function g.calibrate:\n")
+            if (verbose == TRUE) {
+              cat("\n")
+              cat("\nInvestigate calibration of the sensors with function g.calibrate:\n")
+            }
             C = g.calibrate(datafile,
                             params_rawdata = params_rawdata,
                             params_general = params_general,
@@ -311,7 +319,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
         }
       }
       #------------------------------------------------
-      cat("\nExtract signal features (metrics) with the g.getmeta function:\n")
+      if (verbose == TRUE) cat("\nExtract signal features (metrics) with the g.getmeta function:\n")
       M = g.getmeta(datafile,
                     params_metrics = params_metrics,
                     params_rawdata = params_rawdata,
@@ -323,24 +331,29 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                     outputfolder = outputfolder,
                     myfun = myfun)
 
-      if (params_general[["expand_tail_max_hours"]] > 0) {
+      if (!is.null(params_general[["recordingEndSleepHour"]])) {
         # Identify gap between last timestamp and following midnight
         ws3 = M$windowsizes[1]
         ws2 = M$windowsizes[2]
         # Check whether gap is less then criteria
         last_ts = c(Sys.time(), Sys.time())
         secs_to_midnight = c(0, 0)
-        last_ts[1] = iso8601chartime2POSIX(tail(M$metalong$timestamp, n = 1), tz = params_general[["desiredtz"]])
-        last_ts[2] = iso8601chartime2POSIX(tail(M$metashort$timestamp, n = 1), tz = params_general[["desiredtz"]])
-        refhour = (24 + 8 + params_general[["dayborder"]])
+        lastTimeLong = as.character(tail(M$metalong$timestamp, n = 1))
+        lastTimeShort = as.character(tail(M$metashort$timestamp, n = 1))
+        last_ts[1] = iso8601chartime2POSIX(x = lastTimeLong, tz = params_general[["desiredtz"]])
+        last_ts[2] = iso8601chartime2POSIX(x = lastTimeShort, tz = params_general[["desiredtz"]])
+        refhour = 24 + params_general[["dayborder"]]
         for (wsi in 1:2) {
           secs_to_midnight[wsi] = (refhour * 3600) -
-            (as.numeric(format(last_ts[wsi], "%H")) * 3600 +
-               as.numeric(format(last_ts[wsi], "%M")) * 60  +
-               as.numeric(format(last_ts[wsi], "%S")))
+            (as.numeric(format(last_ts[wsi], format = "%H", tz = params_general[["desiredtz"]])) * 3600 +
+               as.numeric(format(last_ts[wsi], format = "%M", tz = params_general[["desiredtz"]])) * 60  +
+               as.numeric(format(last_ts[wsi], format = "%S", tz = params_general[["desiredtz"]])))
         }
-        if (secs_to_midnight[1] <= refhour * 3600) {
+        # only expand if recording ends at 19PM or later
+        max_expand_time = (refhour - (params_general[["recordingEndSleepHour"]] - params_general[["dayborder"]])) * 3600
+        if (secs_to_midnight[1] <= max_expand_time) {
           # If yes, expand data
+          secs_to_midnight = secs_to_midnight + (8 * 3600) # also add 8 hour till the morning
           N_long_epochs_expand = ceiling(secs_to_midnight[1] / ws2) + 1
           N_short_epochs_expand = ceiling(secs_to_midnight[2] / ws3) + 1
           if (N_short_epochs_expand / (ws2 / ws3) < N_long_epochs_expand) {
@@ -360,13 +373,14 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
           M$metashort$timestamp[expand_indices] = POSIXtime2iso8601(expand_tsPOSIX, tz = params_general[["desiredtz"]])
           anglecol = grep(pattern = "angle", x = names(metashort_expand), value = FALSE)
           if (length(anglecol) > 0) {
-            M$metashort[expand_indices,anglecol] = round(sin((1:length(expand_indices)) / (900/ws3))) * 15
+            M$metashort[expand_indices,anglecol] = round(sin((1:length(expand_indices)) / (ws2/ws3))) * 15
           }
           tail_expansion_log = list(short = length(expand_indices))
           # Expand metalong
           NR = nrow(M$metalong)
           metalong_expand = M$metalong[NR,]
           metalong_expand[, grep(pattern = "timestamp", x = names(metalong_expand), invert = TRUE, value = FALSE)] = 0
+          metalong_expand[, "nonwearscore"] = -1
           metalong_expand$en = tail(M$metalong$en, n = 1)
           expand_indices = (NR + 1):(NR + N_long_epochs_expand)
           expand_tsPOSIX = seq(last_ts[1] + ws2, last_ts[1] + (N_long_epochs_expand * ws2), by = ws2)
@@ -379,7 +393,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
         }
       }
       #------------------------------------------------
-      cat("\nSave .RData-file with: calibration report, file inspection report and all signal features...\n")
+      if (verbose == TRUE) cat("\nSave .RData-file with: calibration report, file inspection report and all signal features...\n")
       # remove directory in filename if present
       filename = unlist(strsplit(fnames[i],"/"))
       if (length(filename) > 0) {
@@ -387,7 +401,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       } else {
         filename = fnames[i]
       }
-      filename_dir = tmp5[i]; filefoldername = tmp6[i]
+      filefoldername = filename_dir = fnames[i] # not used elsewhere in GGIR, but just keeping it for consistency
       if (length(unlist(strsplit(fnames[1], "[.]RD"))) == 1) { # to avoid getting .RData.RData
         filename = paste0(filename,".RData")
       }
@@ -434,7 +448,7 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
         params_general[["do.parallel"]] = FALSE
       }
     } else {
-      cat(paste0("\nparallel processing not possible because number of available cores (",Ncores,") < 4"))
+      if (verbose == TRUE) cat(paste0("\nparallel processing not possible because number of available cores (",Ncores,") < 4"))
       params_general[["do.parallel"]] = FALSE
     }
   }
@@ -454,7 +468,8 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                            "g.getstarttime", "POSIXtime2iso8601",
                            "iso8601chartime2POSIX", "datadir2fnames", "read.myacc.csv",
                            "get_nw_clip_block_params", "get_starttime_weekday_meantemp_truncdata", "ismovisens",
-                           "g.extractheadervars", "g.imputeTimegaps", "parseGT3Xggir")
+                           "g.extractheadervars", "g.imputeTimegaps", "extract_params", "load_params",
+                           "check_params")
       errhand = 'stop'
       # Note: This will not work for cwa files, because those also need Rcpp functions.
       # So, it is probably best to turn off parallel when debugging cwa data.
@@ -466,7 +481,8 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                                                 "do.dev_roll_med_acc_x", "do.dev_roll_med_acc_y", "do.dev_roll_med_acc_z",
                                                 "do.bfen", "do.hfen", "do.hfenplus", "do.lfen",
                                                 "do.lfx", "do.lfy", "do.lfz", "do.hfx", "do.hfy", "do.hfz",
-                                                "do.bfx", "do.bfy", "do.bfz", "do.brondcounts")]))
+                                                "do.bfx", "do.bfy", "do.bfz", "do.brondcounts",
+                                                "do.neishabouricounts")]))
     if (Nmetrics2calc > 4) { #Only give warning when user wants more than 4 metrics.
       warning(paste0("\nExtracting many metrics puts higher demands on memory. Please consider",
                      " reducing the value for argument chunksize or setting do.parallel to FALSE"))
@@ -477,7 +493,8 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
       params_rawdata[["chunksize"]] = 0.4 # put limit to chunksize, because when processing in parallel memory is more limited
     }
 
-    cat(paste0('\n Busy processing ... see ', outputdir, outputfolder,'/meta/basic', ' for progress\n'))
+
+    if (verbose == TRUE) cat(paste0('\n Busy processing ... see ', outputdir, outputfolder,'/meta/basic', ' for progress\n'))
     `%myinfix%` = foreach::`%dopar%`
     output_list = foreach::foreach(i = f0:f1, .packages = packages2passon,
                                    .export = functions2passon, .errorhandling = errhand) %myinfix% {
@@ -485,24 +502,24 @@ g.part1 = function(datadir = c(), outputdir = c(), f0 = 1, f1 = c(),
                                        main_part1(i, params_metrics, params_rawdata,
                                                   params_cleaning, params_general, datadir, fnames, fnamesfull,
                                                   outputdir, myfun, filelist, studyname, ffdone, tmp5, tmp6,
-                                                  use.temp, daylimit, path3, outputfolder, is.mv)
+                                                  use.temp, daylimit, path3, outputfolder, is.mv, verbose)
                                      })
                                      return(tryCatchResult)
                                    }
     on.exit(parallel::stopCluster(cl))
     for (oli in 1:length(output_list)) { # logged error and warning messages
       if (is.null(unlist(output_list[oli])) == FALSE) {
-        cat(paste0("\nErrors and warnings for ",fnames[oli]))
+        if (verbose == TRUE) cat(paste0("\nErrors and warnings for ",fnames[oli]))
         print(unlist(output_list[oli])) # print any error and warnings observed
       }
     }
   } else { # simple loop to process files serially file by file
     for (i in f0:f1) {
-      cat(paste0(i, " "))
+      if (verbose == TRUE) cat(paste0(i, " "))
       main_part1(i, params_metrics, params_rawdata,
                  params_cleaning, params_general, datadir, fnames, fnamesfull,
                  outputdir, myfun, filelist, studyname, ffdone, tmp5, tmp6,
-                 use.temp, daylimit, path3, outputfolder, is.mv)
+                 use.temp, daylimit, path3, outputfolder, is.mv, verbose)
 
     }
   }
