@@ -2,7 +2,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                    params_sleep = c(), params_metrics = c(),
                    params_247 = c(), params_phyact = c(),
                    params_cleaning = c(), params_output = c(),
-                   params_general = c(), ...) {
+                   params_general = c(), verbose = TRUE, ...) {
   options(encoding = "UTF-8")
   Sys.setlocale("LC_TIME", "C") # set language to English
   # description: function called by g.shell.GGIR
@@ -61,9 +61,9 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   nightsummary = M = IMP = sib.cla.sum = c() # declaring variable as otherwise R is confused where they come from, while in fact they are loaded as part of the load operations
   #======================================================================
   # compile lists of milestone data filenames
-  fnames.ms3 = sort(dir(paste(metadatadir, "/meta/ms3.out", sep = "")))
-
-  fnames.ms5 = sort(dir(paste(metadatadir, "/meta/ms5.out", sep = "")))
+  fnames.ms3 = dir(paste(metadatadir, "/meta/ms3.out", sep = ""))
+  
+  fnames.ms5 = dir(paste(metadatadir, "/meta/ms5.out", sep = ""))
   # path to sleeplog milestonedata, if it exists:
   sleeplogRDA = paste(metadatadir, "/meta/sleeplog.RData", sep = "")
   if (file.exists(sleeplogRDA) == TRUE) {
@@ -82,7 +82,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   #------------------------------------------------
   # specify parameters
   ffdone = fnames.ms5 #ffdone is now a list of files that have already been processed by g.part5
-  fnames.ms3 = sort(fnames.ms3)
+  # fnames.ms3 = sort(fnames.ms3)
   if (f1 > length(fnames.ms3)) f1 = length(fnames.ms3) # this is intentionally ms3 and not ms4, do not change!
   params_phyact[["boutdur.mvpa"]] = sort(params_phyact[["boutdur.mvpa"]],decreasing = TRUE)
   params_phyact[["boutdur.lig"]] = sort(params_phyact[["boutdur.lig"]],decreasing = TRUE)
@@ -110,11 +110,12 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                         params_cleaning = c(), params_output = c(),
                         params_general = c(), ms5.out, ms5.outraw,
                         fnames.ms3, sleeplog, logs_diaries,
-                        extractfilenames, referencefnames, folderstructure, fullfilenames, foldernam) {
+                        extractfilenames, referencefnames, folderstructure, 
+                        fullfilenames, foldernam, verbose) {
     tail_expansion_log =  NULL
-    fnames.ms1 = sort(dir(paste(metadatadir, "/meta/basic", sep = "")))
-    fnames.ms2 = sort(dir(paste(metadatadir, "/meta/ms2.out", sep = "")))
-    fnames.ms4 = sort(dir(paste(metadatadir, "/meta/ms4.out", sep = "")))
+    fnames.ms1 = dir(paste(metadatadir, "/meta/basic", sep = ""))
+    fnames.ms2 = dir(paste(metadatadir, "/meta/ms2.out", sep = ""))
+    fnames.ms4 = dir(paste(metadatadir, "/meta/ms4.out", sep = ""))
     nfeatures = 500
     ws3 = params_general[["windowsizes"]][1]
     ds_names = rep("",nfeatures)
@@ -168,11 +169,23 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         # load output g.part1
         selp = which(fnames.ms1 == paste0("meta_", fnames.ms3[i]))
         if (length(selp) != 1) {
-          cat("Warning: Milestone data part 1 could not be retrieved")
+          if (verbose == TRUE) cat("Warning: Milestone data part 1 could not be retrieved")
         }
         load(paste0(metadatadir, "/meta/basic/", fnames.ms1[selp]))
+        # convert to character/numeric if stored as factor in metashort and metalong
+        M$metashort = correctOlderMilestoneData(M$metashort)
+        M$metalong = correctOlderMilestoneData(M$metalong)
         # load output g.part3
         load(paste0(metadatadir, "/meta/ms3.out/", fnames.ms3[i]))
+        # remove expanded time so that it is not used for behavioral classification 
+        if (length(tail_expansion_log) != 0) {
+          expanded_short = which(IMP$r5long == -1)
+          expanded_long = which(IMP$rout$r5 == -1)
+          IMP$metashort = IMP$metashort[-expanded_short,]
+          IMP$rout = IMP$rout[-expanded_long,]
+          M$metashort = M$metashort[-expanded_short,]
+          M$metalong = M$metalong[-expanded_long,]
+        }
         # extract key variables from the mile-stone data: time, acceleration and elevation angle
         # note that this is imputed ACCELERATION because we use this for describing behaviour:
         scale = ifelse(test = grepl("^Brond|^Neishabouri|^ZC", params_general[["acc.metric"]]), yes = 1, no = 1000)
@@ -180,7 +193,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                         guider = rep("unknown", nrow(IMP$metashort)),
                         angle = as.numeric(as.matrix(IMP$metashort[,which(names(IMP$metashort) == "anglez")])) )
         Nts = nrow(ts)
-        if (length(which(names(IMP$metashort) == "anglez")) == 0) {
+        if (length(which(names(IMP$metashort) == "anglez")) == 0 & verbose == TRUE) {
           cat("Warning: anglez not extracted. Please check that do.anglez == TRUE")
         }
         # add non-wear column
@@ -241,6 +254,17 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         if (length(pko) > 0) {
           summarysleep_tmp = summarysleep_tmp[-pko,]
         }
+        # if expanded time with expand_tail_max_hours, then latest wakeup might not be in data
+        # reset latest wakeup to latest observed timestamp
+        if (length(tail_expansion_log) != 0) {
+          last_night = S[which(S$night == max(S$night)),]
+          last_wakeup = last_night$sib.end.time[which(last_night$sib.period == max(last_night$sib.period))]
+          if (!(last_wakeup %in% ts$time)) {
+            replaceLastWakeup = which(S$sib.end.time == last_wakeup)
+            S$sib.end.time[replaceLastWakeup] = ts$time[nrow(ts)]
+          } 
+        }
+        
         for (j in def) { # loop through sleep definitions (defined by angle and time threshold in g.part3)
           ws3new = ws3 # reset wse3new, because if part5_agg2_60seconds is TRUE then this will have been change in the previous iteration of the loop
           if (params_general[["part5_agg2_60seconds"]] == TRUE) {
@@ -257,9 +281,13 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
           hour = tempp$hour
           if (params_general[["dayborder"]] == 0) {
             nightsi = which(sec == 0 & min == 0 & hour == 0)
+            nightsi2 = nightsi # nightsi2 will be used in g.part5.wakesleepwindows
           } else {
             nightsi = which(sec == 0 & min == (params_general[["dayborder"]] - floor(params_general[["dayborder"]])) * 60 & hour == floor(params_general[["dayborder"]])) #shift the definition of midnight if required
+            nightsi2 = which(sec == 0 & min == 0 & hour == 0)
           }
+          # include last window if has been expanded and not present in ts
+          if (length(tail_expansion_log) != 0 & nrow(ts) > max(nightsi)) nightsi[length(nightsi) + 1] = nrow(ts) 
           # create copy of only relevant part of sleep summary dataframe
           summarysleep_tmp2 = summarysleep_tmp[which(summarysleep_tmp$sleepparam == j),]
           S2 = S[S$definition == j,] # simplify to one definition
@@ -271,7 +299,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
           ts$diur = 0
           if (nrow(summarysleep_tmp2) > 0) {
             # Add defenition of wake and sleep windows in diur column of data.frame ts
-            ts = g.part5.wakesleepwindows(ts, summarysleep_tmp2, params_general[["desiredtz"]], nightsi,
+            ts = g.part5.wakesleepwindows(ts, summarysleep_tmp2, params_general[["desiredtz"]], nightsi2,
                                           sleeplog, ws3, Nts, ID, Nepochsinhour)
             # Add first waking up time, if it is missing:
             ts = g.part5.addfirstwake(ts, summarysleep_tmp2, nightsi, sleeplog, ID,
@@ -306,6 +334,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
               } else {
                 nightsi = which(sec == 0 & min == (params_general[["dayborder"]] - floor(params_general[["dayborder"]])) * 60 & hour == floor(params_general[["dayborder"]])) #shift the definition of midnight if required
               }
+              if (length(tail_expansion_log) != 0 & nrow(ts) > max(nightsi)) nightsi[length(nightsi) + 1] = nrow(ts) # include last window
               Nts = nrow(ts)
             }
             # if ("angle" %in% colnames(ts)) {
@@ -315,11 +344,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
             # Use sib.report to classify naps, non-wear and integrate these in time series
             # does not depend on bout detection criteria or window definitions.
             if (params_output[["do.sibreport"]]  == TRUE & length(params_sleep[["nap_model"]]) > 0) {
-              if (params_sleep[["sleeplogidnum"]] == TRUE) {
-                IDtmp = as.numeric(ID)
-              } else {
-                IDtmp = as.character(ID)
-              }
+              IDtmp = as.character(ID)
               sibreport = g.sibreport(ts, ID = IDtmp, epochlength = ws3new, logs_diaries,
                                       desiredtz = params_general[["desiredtz"]])
               # store in csv file:
@@ -329,6 +354,10 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
               }
               sibreport_fname =  paste0(metadatadir,ms5.sibreport,"/sib_report_",fnames.ms3[i],"_",j,".csv")
               write.csv(x = sibreport, file = sibreport_fname, row.names = FALSE)
+              # nap/sib/nonwear overlap analysis
+              
+              # TO DO
+              
               # nap detection
               if (params_general[["acc.metric"]] != "ENMO" |
                   params_sleep[["HASIB.algo"]] != "vanHees2015") {
@@ -443,6 +472,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                         if ((qqq[2] - qqq[1]) * ws3new > 900) {
                           fi = 1
                           # START STORING BASIC INFORMATION
+                          if (di > nrow(dsummary)) dsummary = rbind(dsummary, matrix(data = "", nrow = 1, ncol = ncol(dsummary)))
                           dsummary[di,fi:(fi + 2)] = c(ID, fnames.ms3[i], wi)
                           ds_names[fi:(fi + 2)] = c("ID", "filename", "window_number"); fi = fi + 3
                           if (timewindowi == "WW") {
@@ -789,15 +819,14 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                           ds_names[fi:(fi + 3)] = c("Nblocks_day_total_IN", "Nblocks_day_total_LIG",
                                                     "Nblocks_day_total_MOD", "Nblocks_day_total_VIG")
                           fi = fi + 4
-                          dsummary[di, fi:(fi + 6)] = c(params_phyact[["boutcriter.in"]],
+                          dsummary[di, fi:(fi + 5)] = c(params_phyact[["boutcriter.in"]],
                                                         params_phyact[["boutcriter.lig"]],
                                                         params_phyact[["boutcriter.mvpa"]],
                                                         paste(params_phyact[["boutdur.in"]], collapse = "_"),
                                                         paste(params_phyact[["boutdur.lig"]], collapse = "_"),
-                                                        paste(params_phyact[["boutdur.mvpa"]], collapse = "_"),
-                                                        params_phyact[["bout.metric"]])
-                          ds_names[fi:(fi + 6)] = c("boutcriter.in", "boutcriter.lig", "boutcriter.mvpa",
-                                                    "boutdur.in",  "boutdur.lig", "boutdur.mvpa", "bout.metric"); fi = fi + 7
+                                                        paste(params_phyact[["boutdur.mvpa"]], collapse = "_"))
+                          ds_names[fi:(fi + 5)] = c("boutcriter.in", "boutcriter.lig", "boutcriter.mvpa",
+                                                    "boutdur.in",  "boutdur.lig", "boutdur.mvpa"); fi = fi + 6
                           #===========================
                           # Intensity gradient over waking hours
                           if (length(params_247[["iglevels"]]) > 0) {
@@ -906,14 +935,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         }
         output = data.frame(dsummary,stringsAsFactors = FALSE)
         names(output) = ds_names
-         if (params_cleaning[["excludefirstlast.part5"]] == TRUE) {
-          output$window_number = as.numeric(output$window_number)
-          cells2exclude = c(which(output$window_number == min(output$window_number,na.rm = TRUE)),
-                            which(output$window_number == max(output$window_number,na.rm = TRUE)))
-          if (length(cells2exclude) > 0) {
-            output = output[-cells2exclude,]
-          }
-        }
+        
         # correct definition of sleep log availability for window = WW, because now it
         # also relies on sleep log from previous night
         whoareWW = which(output$window == "WW") # look up WW
@@ -935,7 +957,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         # tidy up output data frame, because it may have a lot of empty rows and columns
         emptyrows = which(output[,1] == "" & output[,2] == "")
         if (length(emptyrows) > 0) output = output[-emptyrows,]
-        lastcolumn = which(colnames(output) == "bout.metric")
+        lastcolumn = which(colnames(output) == "boutdur.mvpa")
         if (length(lastcolumn) > 0) {
           if (ncol(output) > lastcolumn) {
             emptycols = sapply(output, function(x)all(x == ""))# Find columns filled with missing values which(output[1,] == "" & output[2,] == "")
@@ -953,7 +975,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
           if (length(output) > 0) {
             if (nrow(output) > 0) {
               save(output, tail_expansion_log, file = paste(metadatadir,
-                                        ms5.out, "/", fnames.ms3[i], sep = ""))
+                                                            ms5.out, "/", fnames.ms3[i], sep = ""))
             }
           }
         }
@@ -978,12 +1000,12 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         params_general[["do.parallel"]] = FALSE
       }
     } else {
-      cat(paste0("\nparallel processing not possible because number of available cores (",Ncores,") < 4"))
+      if (verbose == TRUE) cat(paste0("\nparallel processing not possible because number of available cores (",Ncores,") < 4"))
       params_general[["do.parallel"]] = FALSE
     }
   }
   if (params_general[["do.parallel"]] == TRUE) {
-    cat(paste0('\n Busy processing ... see ', metadatadir, ms5.out, ' for progress\n'))
+    if (verbose == TRUE) cat(paste0('\n Busy processing ... see ', metadatadir, ms5.out, ' for progress\n'))
     # check whether we are in development mode:
     GGIRinstalled = is.element('GGIR', installed.packages()[,1])
     packages2passon = functions2passon = NULL
@@ -999,7 +1021,8 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                            "g.part5.onsetwaketiming", "g.part5.wakesleepwindows",
                            "g.part5.savetimeseries", "g.fragmentation", "g.intensitygradient",
                            "g.part5.handle_lux_extremes", "g.part5.lux_persegment", "g.sibreport",
-                           "extract_params", "load_params", "check_params")
+                           "extract_params", "load_params", "check_params",
+                           "correctOlderMilestoneData")
       errhand = 'stop'
     }
     i = 0 # declare i because foreach uses it, without declaring it
@@ -1014,20 +1037,20 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                                                   params_general, ms5.out, ms5.outraw,
                                                   fnames.ms3, sleeplog, logs_diaries,
                                                   extractfilenames, referencefnames, folderstructure,
-                                                  fullfilenames, foldername)
+                                                  fullfilenames, foldername, verbose)
                                      })
                                      return(tryCatchResult)
                                    }
     on.exit(parallel::stopCluster(cl))
     for (oli in 1:length(output_list)) { # logged error and warning messages
       if (is.null(unlist(output_list[oli])) == FALSE) {
-        cat(paste0("\nErrors and warnings for ", fnames.ms3[oli]))
+        if (verbose == TRUE) cat(paste0("\nErrors and warnings for ", fnames.ms3[oli]))
         print(unlist(output_list[oli])) # print any error and warnings observed
       }
     }
   } else {
     for (i in f0:f1) {
-      cat(paste0(i, " "))
+      if (verbose == TRUE) cat(paste0(i, " "))
       main_part5(i, metadatadir, f0, f1,
                  params_sleep, params_metrics,
                  params_247, params_phyact,
@@ -1035,7 +1058,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                  params_general, ms5.out, ms5.outraw,
                  fnames.ms3, sleeplog, logs_diaries,
                  extractfilenames, referencefnames, folderstructure,
-                 fullfilenames, foldername)
+                 fullfilenames, foldername, verbose)
     }
   }
 }
