@@ -21,7 +21,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                         HASPT.ignore.invalid = FALSE,
                         loglocation = c(), colid = 1, coln1 = 2,
                         nnights = c(),
-                        relyonguider = FALSE, sleeplogidnum = TRUE,
+                        relyonguider = FALSE,
                         def.noc.sleep = 1,
                         sleeplogsep = ",", sleepwindowType = "SPT",
                         possible_nap_window = c(9, 18),
@@ -58,13 +58,13 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
       rmc.unit.time = "POSIX", rmc.format.time = "%Y-%m-%d %H:%M:%OS",
       rmc.bitrate = c(),  rmc.dynamic_range = c(),
       rmc.unsignedbit = TRUE, rmc.origin = "1970-01-01",
-      rmc.desiredtz = "",  rmc.sf = c(),
+      rmc.desiredtz = "", rmc.configtz = c(),  rmc.sf = c(),
       rmc.headername.sf = c(), rmc.headername.sn = c(),
       rmc.headername.recordingid = c(), rmc.header.structure = c(),
       rmc.check4timegaps = FALSE,  rmc.noise = 13,
       rmc.col.wear = c(), rmc.doresample = FALSE,
       interpolationType = 1,
-      imputeTimegaps = TRUE, loadGENEActiv = "GGIRread")
+      imputeTimegaps = TRUE)
   }
   if ("247" %in% group) {
     params_247 = list(qwindow = c(0,24), qlevels = c(),
@@ -78,12 +78,12 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
   }
   if ("phyact" %in% group) {
     params_phyact = list(mvpathreshold = 100, boutcriter = 0.8,
-                         mvpadur = c(1,5,10), closedbout = FALSE,
+                         mvpadur = c(1,5,10),
                          boutcriter.in = 0.9, boutcriter.lig = 0.8,
                          boutcriter.mvpa = 0.8, threshold.lig = 40,
                          threshold.mod = 100, threshold.vig = 400,
                          boutdur.mvpa = c(1,5,10), boutdur.in = c(10,20,30),
-                         boutdur.lig = c(1,5,10), frag.metrics = c(), bout.metric = 6)
+                         boutdur.lig = c(1,5,10), frag.metrics = c())
   }
   if ("cleaning" %in% group) {
     params_cleaning = list(includedaycrit = 16, ndayswindow = 7,
@@ -95,7 +95,8 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                            excludefirstlast = FALSE, #<= to cleaning
                            includenightcrit = 16, #<= to cleaning
                            excludefirst.part4 = FALSE, # => to cleaning
-                           excludelast.part4 = FALSE, max_calendar_days = 0)
+                           excludelast.part4 = FALSE, max_calendar_days = 0,
+                           nonWearEdgeCorrection = TRUE)
   }
   if ("output" %in% group) {
     params_output = list(epochvalues2csv = FALSE, save_ms5rawlevels = FALSE,
@@ -114,7 +115,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                           desiredtz = "", configtz = c(), idloc = 1, dayborder = 0,
                           part5_agg2_60seconds = FALSE,
                           sensor.location = "wrist",
-                          expand_tail_max_hours = 0)
+                          expand_tail_max_hours = NULL, recordingEndSleepHour = NULL)
   }
   # }
   invisible(list(params_sleep = params_sleep,
