@@ -76,9 +76,7 @@ test_that("g.readaccfile and g.inspectfile can read genea, gt3x and cwa files co
   expect_equal(decn,".")
   decn =  expect_warning(g.dotorcomma(wavfile, dformat = 3, mon = 4, desiredtz = desiredtz))
   expect_equal(decn,".")
-  decn =  g.dotorcomma(GAfile, dformat = 1, mon = 2, desiredtz = desiredtz, loadGENEActiv = "GGIRread")
-  expect_equal(decn,".")
-  decn =  expect_warning(g.dotorcomma(GAfile, dformat = 1, mon = 2, desiredtz = desiredtz, loadGENEActiv = "GENEAread"))
+  decn =  g.dotorcomma(GAfile, dformat = 1, mon = 2, desiredtz = desiredtz)
   expect_equal(decn,".")
   filequality = list(filecorrupt = FALSE, filetooshort = FALSE)
   dayborder = 0
@@ -96,7 +94,7 @@ test_that("g.readaccfile and g.inspectfile can read genea, gt3x and cwa files co
                                          decn = ".", dayborder = dayborder, ws = 3,
                                          desiredtz = desiredtz, PreviousEndPage = 1, inspectfileobject = IGA)
   expect_equal(cwa_read$P$header$blocks, 145)
-  expect_equal(round(cwa_read$P$data[200, 6], digits = 4), 4.1133)
+  expect_equal(round(cwa_read$P$data[200, 6], digits = 4), 0)
   
   expect_equal(nrow(genea_read$P$header), 18)
   expect_equal(sum(genea_read$P$rawxyz[20,]), 1000)
